@@ -298,13 +298,13 @@ static void activate_one_dropping(const struct blubat *blubat) {
 
   bptr->x = x;
   bptr->y = y;
-  bptr->dx = (xship + surfaces_ship->surfaces[0]->w / 2 - x) / 51.1;
+  bptr->dx = (shipdata.xship + surfaces_ship->surfaces[0]->w / 2 - x) / 51.1;
   if(bptr->dx > maxdx) {
     x = bptr->dx / maxdx;	//Scaling factor, otherwise our blubats always miss...
     bptr->dx = maxdx;
     bptr->dy *= x;
   }
-  bptr->dy = (yship + surfaces_ship->surfaces[0]->h / 2 - y) / 51.1;
+  bptr->dy = (shipdata.yship + surfaces_ship->surfaces[0]->h / 2 - y) / 51.1;
   if(bptr->dy > maxdy) {
     y = bptr->dy / maxdy;	//Scaling factor
     bptr->dx *= y;
@@ -352,7 +352,7 @@ int check_blubat_hit(int ylaser, int maxx) {
     float x = bluptr->x;
     float y = bluptr->y;
     if(ylaser >= y && ylaser < y + 16) {
-      if(x <= maxx && xship < x) {
+      if(x <= maxx && shipdata.xship < x) {
 #ifdef DEBUG
 	printf("bluptr=%p blu_end=%p ylaser=%d maxx=%d x=%e y=%e\n", bluptr,
 	       blu_end, ylaser, maxx, bluptr->x, bluptr->y);
