@@ -2,7 +2,10 @@
 #define __BLUBATS_H__
 #include <SDL/SDL.h>
 #include "u-iff.h"
-#include "rockdodger_globals.h"
+#include "datafun.h"
+#include "globals.h"
+
+sdl_surfaces_t *surf_blubats; //!< blubat animation sequence
 
 /*! \brief Initialise blubats
  *
