@@ -63,9 +63,8 @@ void update_rocks(void);
  * Create a rock, if maximum number of rocks reached function returns
  * immediately.
  *
- * \param rockspeed current default speed of the rock, modified by a random amount
  */
-void create_rock(float rockspeed);
+void create_rock(void);
 
 /*! \brief Initialise rock data.
  *
@@ -75,4 +74,19 @@ void create_rock(float rockspeed);
  */
 void *init_rocks(void);
 
+/*! \brief Reset rock system
+ *
+ * Reset the rock system to sensible values. This function should be
+ * called on every start of a game.
+ */
+void reset_rocks(void);
+
+/*! \brief Create a rock while in game.
+ *
+ * This function will update the rock countdown and create a new rock
+ * if the correct level has been reached. Call this function once per
+ * frame if in-game mode.
+ */
+void ingame_maybe_rock();
+
 #endif
