@@ -16,8 +16,7 @@ static struct black_point_struct black_point[MAX_BLACK_POINTS], *blackptr =
 SDL_Surface *surf_small_ship;
 sdl_surfaces_t *surfaces_ship;
 struct sprite ship_sprite;
-float xship, yship;
-float xvel, yvel;
+ship_t shipdata;
 
 
 void draw_little_ships(int nships, SDL_Surface * surf_screen) {
@@ -37,8 +36,8 @@ void draw_ship(SDL_Surface * surf_screen) {
   static SDL_Rect dest;
   dest.w = 0; //src.w;
   dest.h = 0; //src.h;
-  dest.x = (int) xship;
-  dest.y = (int) yship;
+  dest.x = (int) shipdata.xship;
+  dest.y = (int) shipdata.yship;
   SDL_BlitSurface(get_current_sprite_surface(&ship_sprite, last_ticks), NULL, surf_screen, &dest);
 }
 
@@ -121,8 +120,8 @@ void draw_ship_shield(SDL_Surface * surf_screen) {
 
   shieldpulse += 0.1;
   for(p = black_point; p < blackptr; p++) {
-    x = p->x + (int) xship + (rnd() + rnd() - 1) * sin(shieldpulse) * 4 + 1;
-    y = p->y + (int) yship + (rnd() + rnd() - 1) * sin(shieldpulse) * 4 + 1;
+    x = p->x + (int) shipdata.xship + (rnd() + rnd() - 1) * sin(shieldpulse) * 4 + 1;
+    y = p->y + (int) shipdata.yship + (rnd() + rnd() - 1) * sin(shieldpulse) * 4 + 1;
     if(x > 0 && y > 0 && x < xsize && y < ysize) {
       int offset = surf_screen->pitch / sizeof(RD_VIDEO_TYPE) * y + x;
       raw_pixels[offset] = c;
@@ -143,7 +142,7 @@ int ship_check_collision(SDL_Surface * surf_screen) {
   // on the ship are still black, and not covered up by rocks
   for(p = black_point; p < blackptr; p++) {
     int offset =
-      surf_screen->pitch / sizeof(RD_VIDEO_TYPE) * (p->y + (int) yship) + p->x + (int) xship;
+      surf_screen->pitch / sizeof(RD_VIDEO_TYPE) * (p->y + (int) shipdata.yship) + p->x + (int) shipdata.xship;
     if(raw_pixels[offset]) {
       // Set the bang flag, a collision with something happened
       bang = 1;
@@ -158,30 +157,30 @@ void ship_update_position(void) {
   SDL_Surface *surf_ship = get_current_sprite_surface(&ship_sprite, last_ticks);
 
   // FRICTION? In space? Oh well.
-  xvel *= powf(0.9, movementrate);
-  yvel *= powf(0.9, movementrate);
-  // if (abs(xvel)<0.00001) xvel=0;
-  // if (abs(yvel)<0.00001) yvel=0;
+  shipdata.xvel *= powf(0.9, movementrate);
+  shipdata.yvel *= powf(0.9, movementrate);
+  // if (abs(shipdata.xvel)<0.00001) shipdata.xvel=0;
+  // if (abs(shipdata.yvel)<0.00001) shipdata.yvel=0;
 
   // INERTIA
-  xship += xvel * movementrate;
-  yship += yvel * movementrate;
+  shipdata.xship += shipdata.xvel * movementrate;
+  shipdata.yship += shipdata.yvel * movementrate;
 
   // BOUNCE X  (okay, throwing all pretense of realism out the
   // window)
-  if(xship < 0 || xship > xsize - surf_ship->w) {
+  if(shipdata.xship < 0 || shipdata.xship > xsize - surf_ship->w) {
     // BOUNCE from left and right wall
-    xship -= xvel * movementrate;
-    xvel *= -0.99;
+    shipdata.xship -= shipdata.xvel * movementrate;
+    shipdata.xvel *= -0.99;
   }
   // BOUNCE Y
-  if(yship < 0 || yship > ysize - surf_ship->h) {
+  if(shipdata.yship < 0 || shipdata.yship > ysize - surf_ship->h) {
     // BOUNCE from top and bottom wall
-    yship -= yvel * movementrate;
-    yvel *= -0.99;
+    shipdata.yship -= shipdata.yvel * movementrate;
+    shipdata.yvel *= -0.99;
   }
 }
 
 void way_of_the_exploding_ship(void) {
-  makebangdots(xship, yship, xvel, yvel, get_current_sprite_surface(&ship_sprite, last_ticks), 30, 3);
+  makebangdots(shipdata.xship, shipdata.yship, shipdata.xvel, shipdata.yvel, get_current_sprite_surface(&ship_sprite, last_ticks), 30, 3);
 }
