@@ -4,14 +4,14 @@
 #include <SDL/SDL.h>
 #include <SDL/SDL_mixer.h>
 #include "datafun.h"
-#include "rockdodger_globals.h"
+#include "globals.h"
 
 #define CONDERROR(a) if ((a)) {fprintf(stderr,"Error: %s\n",SDL_GetError());exit(1);}
 #define NULLERROR(a) CONDERROR((a)==NULL)
 
 #define NUM_TUNES		5
 #define SOUND_BANG		0
-#define NUM_SOUNDS		10
+#define NUM_SOUNDS		12
 
 int sfx_enabled;
 
@@ -32,9 +32,10 @@ static int playing = -1;
 
 const char *wav_file[] = {
   "booom.wav", "cboom.wav", "boom.wav", "bzboom.wav",
-  "speedup.wav",
-  "drip.wav",
-  "fart.1.aiff", "fart.2.aiff", "fart.3.aiff", "fart.4.aiff"
+  "speedup.wav", /* 4 */
+  "drip.wav", /* 5 */
+  "fart.1.aiff", "fart.2.aiff", "fart.3.aiff", "fart.4.aiff",
+  "shockwave-water.aiff" /* 10, from ST-45 */, "xbad.aiff" /* 11, modified from ST-15 */
 };
 
 const char *tune_file[] = {
@@ -95,12 +96,20 @@ int init_sound() {
 
 void play_sound(int i) {
 #ifdef DEBUG
-  printf("play sound %d on first free channel\n", i);
+  int uc = -1; //used channel
 #endif
+
   if(sfx_enabled) {
     if(i >= NUM_SOUNDS) fprintf(stderr, "Sound number %d is >= than %d!\n", i, NUM_SOUNDS);
-    Mix_PlayChannel(-1, wav[i], 0);
+#ifdef DEBUG
+    uc = Mix_PlayChannel(-1, wav[i], 0);
+#else
+    (void) Mix_PlayChannel(-1, wav[i], 0);
+#endif
   }
+#ifdef DEBUG
+  printf("play sound %d on first free channel (%d)\n", i, uc);
+#endif
 }
 
 
